# Testes unitários do Texto-Transformer

Foram realizados testes unitários com unittest dos modelos AlbertModel(en), BertModel(en, pt-br), DistilBertModel(en), GPT2Model(en), OpenAIGPTModel(en), RobertaModel(en), XLMRoberta(en), XLNetModel(en) e T5EncoderModel(en, pt-br) nos idiomas inglês(en) e português(pt-br).
